from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.user_role import UserRole
from ..models.user_status import UserStatus
from ..types import UNSET, Unset

T = TypeVar("T", bound="UserAdminUpdate")


@attr.s(auto_attribs=True)
class UserAdminUpdate:
    """ User schema to receive from PUT /{user_id}/admin endpoint. """

    role: Union[Unset, UserRole] = UNSET
    org_contact: Union[Unset, bool] = UNSET
    status: Union[Unset, UserStatus] = UNSET
    group_ids: Union[Unset, List[int]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        role: Union[Unset, UserRole] = UNSET
        if not isinstance(self.role, Unset):
            role = self.role

        org_contact = self.org_contact
        status: Union[Unset, UserStatus] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status

        group_ids: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.group_ids, Unset):
            group_ids = self.group_ids

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if role is not UNSET:
            field_dict["role"] = role
        if org_contact is not UNSET:
            field_dict["org_contact"] = org_contact
        if status is not UNSET:
            field_dict["status"] = status
        if group_ids is not UNSET:
            field_dict["group_ids"] = group_ids

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        role: Union[Unset, UserRole] = UNSET
        _role = d.pop("role", UNSET)
        if not isinstance(_role, Unset):
            role = UserRole(_role)

        org_contact = d.pop("org_contact", UNSET)

        status: Union[Unset, UserStatus] = UNSET
        _status = d.pop("status", UNSET)
        if not isinstance(_status, Unset):
            status = UserStatus(_status)

        group_ids = cast(List[int], d.pop("group_ids", UNSET))

        user_admin_update = cls(
            role=role,
            org_contact=org_contact,
            status=status,
            group_ids=group_ids,
        )

        user_admin_update.additional_properties = d
        return user_admin_update

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="FolderOut")


@attr.s(auto_attribs=True)
class FolderOut:
    """ Folder schema to output from GET methods. """

    name: str
    id: int
    org_id: int
    path: str
    created_on: datetime.datetime
    updated_on: datetime.datetime
    parent_id: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        id = self.id
        org_id = self.org_id
        path = self.path
        created_on = self.created_on.isoformat()

        updated_on = self.updated_on.isoformat()

        parent_id = self.parent_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "id": id,
                "org_id": org_id,
                "path": path,
                "created_on": created_on,
                "updated_on": updated_on,
            }
        )
        if parent_id is not UNSET:
            field_dict["parent_id"] = parent_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        id = d.pop("id")

        org_id = d.pop("org_id")

        path = d.pop("path")

        created_on = isoparse(d.pop("created_on"))

        updated_on = isoparse(d.pop("updated_on"))

        parent_id = d.pop("parent_id", UNSET)

        folder_out = cls(
            name=name,
            id=id,
            org_id=org_id,
            path=path,
            created_on=created_on,
            updated_on=updated_on,
            parent_id=parent_id,
        )

        folder_out.additional_properties = d
        return folder_out

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.timezone import Timezone
from ..models.user_role import UserRole
from ..types import UNSET, Unset

T = TypeVar("T", bound="UserCreate")


@attr.s(auto_attribs=True)
class UserCreate:
    """ User schema to receive from POST method. """

    org_id: int
    first_name: str
    last_name: str
    email: str
    role: UserRole
    timezone: Timezone
    language: Union[Unset, None] = UNSET
    org_contact: Union[Unset, bool] = False
    group_ids: Union[Unset, List[int]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        org_id = self.org_id
        first_name = self.first_name
        last_name = self.last_name
        email = self.email
        role = self.role.value

        timezone = self.timezone.value

        language = None

        org_contact = self.org_contact
        group_ids: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.group_ids, Unset):
            group_ids = self.group_ids

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "org_id": org_id,
                "first_name": first_name,
                "last_name": last_name,
                "email": email,
                "role": role,
                "timezone": timezone,
            }
        )
        if language is not UNSET:
            field_dict["language"] = language
        if org_contact is not UNSET:
            field_dict["org_contact"] = org_contact
        if group_ids is not UNSET:
            field_dict["group_ids"] = group_ids

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        org_id = d.pop("org_id")

        first_name = d.pop("first_name")

        last_name = d.pop("last_name")

        email = d.pop("email")

        role = UserRole(d.pop("role"))

        timezone = Timezone(d.pop("timezone"))

        language = None

        org_contact = d.pop("org_contact", UNSET)

        group_ids = cast(List[int], d.pop("group_ids", UNSET))

        user_create = cls(
            org_id=org_id,
            first_name=first_name,
            last_name=last_name,
            email=email,
            role=role,
            timezone=timezone,
            language=language,
            org_contact=org_contact,
            group_ids=group_ids,
        )

        user_create.additional_properties = d
        return user_create

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="EntityInDB")


@attr.s(auto_attribs=True)
class EntityInDB:
    """ Document entity schema. """

    chunk_id: str
    type: str
    text: str
    id: int
    version_id: int
    page_start: int
    page_end: int
    div_start: Union[Unset, int] = UNSET
    starts_at: Union[Unset, int] = UNSET
    div_end: Union[Unset, int] = UNSET
    ends_at: Union[Unset, int] = UNSET
    score: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        chunk_id = self.chunk_id
        type = self.type
        text = self.text
        id = self.id
        version_id = self.version_id
        page_start = self.page_start
        page_end = self.page_end
        div_start = self.div_start
        starts_at = self.starts_at
        div_end = self.div_end
        ends_at = self.ends_at
        score = self.score

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "chunk_id": chunk_id,
                "type": type,
                "text": text,
                "id": id,
                "version_id": version_id,
                "page_start": page_start,
                "page_end": page_end,
            }
        )
        if div_start is not UNSET:
            field_dict["div_start"] = div_start
        if starts_at is not UNSET:
            field_dict["starts_at"] = starts_at
        if div_end is not UNSET:
            field_dict["div_end"] = div_end
        if ends_at is not UNSET:
            field_dict["ends_at"] = ends_at
        if score is not UNSET:
            field_dict["score"] = score

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        chunk_id = d.pop("chunk_id")

        type = d.pop("type")

        text = d.pop("text")

        id = d.pop("id")

        version_id = d.pop("version_id")

        page_start = d.pop("page_start")

        page_end = d.pop("page_end")

        div_start = d.pop("div_start", UNSET)

        starts_at = d.pop("starts_at", UNSET)

        div_end = d.pop("div_end", UNSET)

        ends_at = d.pop("ends_at", UNSET)

        score = d.pop("score", UNSET)

        entity_in_db = cls(
            chunk_id=chunk_id,
            type=type,
            text=text,
            id=id,
            version_id=version_id,
            page_start=page_start,
            page_end=page_end,
            div_start=div_start,
            starts_at=starts_at,
            div_end=div_end,
            ends_at=ends_at,
            score=score,
        )

        entity_in_db.additional_properties = d
        return entity_in_db

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['recital',
 'recital.api',
 'recital.api.background_tasks',
 'recital.api.document_viewer',
 'recital.api.extract_configuration',
 'recital.api.extract_models',
 'recital.api.extract_predictions',
 'recital.api.extract_task_results',
 'recital.api.extract_tasks',
 'recital.api.file_items',
 'recital.api.file_versions',
 'recital.api.folders',
 'recital.api.folders_content',
 'recital.api.hierarchy',
 'recital.api.html_representations',
 'recital.api.indexing',
 'recital.api.indexing_tasks',
 'recital.api.metadata_import',
 'recital.api.metadata_value_assignment',
 'recital.api.named_entities',
 'recital.api.organizations',
 'recital.api.regex_validation',
 'recital.api.reports',
 'recital.api.search',
 'recital.api.search_bar_autocomplete',
 'recital.api.search_history',
 'recital.api.version_contents',
 'recital.models']

package_data = \
{'': ['*']}

install_requires = \
['attrs>=20.1.0,<21.0.0',
 'httpx>=0.15.4,<0.18.0',
 'python-dateutil>=2.8.0,<3.0.0']

setup_kwargs = {
    'name': 'recital',
    'version': '0.2.0',
    'description': 'A client library for accessing recital',
    'long_description': '# reciTAL Client\n\nA client library for accessing reciTAL\'s API. :tada:\n\n## Installation\n\nIt\'s easy. Don\'t worry.:smiley:\n\nYou just need to run the following:\n\n```bash\npip install recital\n```\n\n## Usage\n\nFirst, you\'ll need to create the client:\n\n```python\nfrom recital import RecitalClient\n\nclient = RecitalClient(username="username", password="password")\n```\n\nNow call your endpoint and use your models:\n\n```python\nfrom recital.models import MyDataModel\nfrom recital.api.my_tag import get_my_data_model\nfrom recital.types import Response\n\nmy_data: MyDataModel = get_my_data_model.sync(client=client)\n# or if you need more info (e.g. status_code)\nresponse: Response[MyDataModel] = get_my_data_model.sync_detailed(client=client)\n```\n\nOr do the same thing with an async version:\n\n```python\nfrom recital.models import MyDataModel\nfrom recital.api.my_tag import get_my_data_model\nfrom recital.types import Response\n\nmy_data: MyDataModel = await get_my_data_model.asyncio(client=client)\nresponse: Response[MyDataModel] = await get_my_data_model.asyncio_detailed(client=client)\n```\n\nThings to know:\n1. Every path/method combo becomes a Python module with four functions:\n    1. `sync`: Blocking request that returns parsed data (if successful) or `None`\n    1. `sync_detailed`: Blocking request that always returns a `Request`, optionally with `parsed` set if the request was successful.\n    1. `asyncio`: Like `sync` but the async instead of blocking\n    1. `asyncio_detailed`: Like `sync_detailed` by async instead of blocking\n\n1. All path/query params, and bodies become method arguments.\n1. If your endpoint had any tags on it, the first tag will be used as a module name for the function (my_tag above)\n1. Any endpoint which did not have a tag will be in `recital.api.default`\n\n## Building / publishing this Client\nThis project uses [Poetry](https://python-poetry.org/) to manage dependencies  and packaging.  Here are the basics:\n1. Update the metadata in pyproject.toml (e.g. authors, version)\n1. If you\'re using a private repository, configure it with Poetry\n    1. `poetry config repositories.<your-repository-name> <url-to-your-repository>`\n    1. `poetry config http-basic.<your-repository-name> <username> <password>`\n1. Publish the client with `poetry publish --build -r <your-repository-name>` or, if for public PyPI, just `poetry publish --build`\n\nIf you want to install this client into another project without publishing it (e.g. for development) then:\n1. If that project **is using Poetry**, you can simply do `poetry add <path-to-this-client>` from that project\n1. If that project is not using Poetry:\n    1. Build a wheel with `poetry build -f wheel`\n    1. Install that wheel from the other project `pip install <path-to-wheel>`\n',
    'author': None,
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.google_drive_entity import GoogleDriveEntity
from ..types import UNSET, Unset

T = TypeVar("T", bound="GoogleFoldersOut")


@attr.s(auto_attribs=True)
class GoogleFoldersOut:
    """ Google Drive folders model returned from the API. """

    folders: List[GoogleDriveEntity]
    next_page_token: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        folders = []
        for folders_item_data in self.folders:
            folders_item = folders_item_data.to_dict()

            folders.append(folders_item)

        next_page_token = self.next_page_token

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "folders": folders,
            }
        )
        if next_page_token is not UNSET:
            field_dict["next_page_token"] = next_page_token

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        folders = []
        _folders = d.pop("folders")
        for folders_item_data in _folders:
            folders_item = GoogleDriveEntity.from_dict(folders_item_data)

            folders.append(folders_item)

        next_page_token = d.pop("next_page_token", UNSET)

        google_folders_out = cls(
            folders=folders,
            next_page_token=next_page_token,
        )

        google_folders_out.additional_properties = d
        return google_folders_out

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.metadata_date_range import MetadataDateRange
from ..models.metadata_type import MetadataType
from ..types import UNSET, Unset

T = TypeVar("T", bound="MetadataCreate")


@attr.s(auto_attribs=True)
class MetadataCreate:
    """ Metadata schema for metadata creation. """

    name: str
    value_type: Union[Unset, MetadataType] = UNSET
    value: Union[Unset, MetadataDateRange, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        value_type: Union[Unset, MetadataType] = UNSET
        if not isinstance(self.value_type, Unset):
            value_type = self.value_type

        value: Union[Unset, MetadataDateRange, str]
        if isinstance(self.value, Unset):
            value = UNSET
        elif isinstance(self.value, MetadataDateRange):
            value = UNSET
            if not isinstance(self.value, Unset):
                value = self.value.to_dict()

        else:
            value = self.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
            }
        )
        if value_type is not UNSET:
            field_dict["value_type"] = value_type
        if value is not UNSET:
            field_dict["value"] = value

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        value_type: Union[Unset, MetadataType] = UNSET
        _value_type = d.pop("value_type", UNSET)
        if not isinstance(_value_type, Unset):
            value_type = MetadataType(_value_type)

        def _parse_value(data: Any) -> Union[Unset, MetadataDateRange, str]:
            data = None if isinstance(data, Unset) else data
            value: Union[Unset, MetadataDateRange, str]
            try:
                value = UNSET
                _value = data
                if not isinstance(_value, Unset):
                    value = MetadataDateRange.from_dict(_value)

                return value
            except:  # noqa: E722
                pass
            return cast(Union[Unset, MetadataDateRange, str], data)

        value = _parse_value(d.pop("value", UNSET))

        metadata_create = cls(
            name=name,
            value_type=value_type,
            value=value,
        )

        metadata_create.additional_properties = d
        return metadata_create

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="PasswordPolicyExpected")


@attr.s(auto_attribs=True)
class PasswordPolicyExpected:
    """Policy schema that represents the expected password policy
    for login endpoint."""

    min_length: int
    digit: bool
    upper: bool
    lower: bool
    special: bool
    max_similarity: float
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        min_length = self.min_length
        digit = self.digit
        upper = self.upper
        lower = self.lower
        special = self.special
        max_similarity = self.max_similarity

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "min_length": min_length,
                "digit": digit,
                "upper": upper,
                "lower": lower,
                "special": special,
                "max_similarity": max_similarity,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        min_length = d.pop("min_length")

        digit = d.pop("digit")

        upper = d.pop("upper")

        lower = d.pop("lower")

        special = d.pop("special")

        max_similarity = d.pop("max_similarity")

        password_policy_expected = cls(
            min_length=min_length,
            digit=digit,
            upper=upper,
            lower=lower,
            special=special,
            max_similarity=max_similarity,
        )

        password_policy_expected.additional_properties = d
        return password_policy_expected

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class UserRole(str, Enum):
    BASIC = "basic"
    ORGADMIN = "orgadmin"
    SYSADMIN = "sysadmin"
    SERVICE = "service"
    BASICORGADMINSYSADMINSERVICE = "basic+orgadmin+sysadmin+service"
    SYSADMINORGADMIN = "sysadmin+orgadmin"
    BASICORGADMINSYSADMIN = "basic+orgadmin+sysadmin"
    BASICORGADMIN = "basic+orgadmin"
    SERVICESYSADMIN = "service+sysadmin"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.extract_result_validate_out import ExtractResultValidateOut
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Response


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    task_id: int,
) -> Dict[str, Any]:
    url = "{}/api/v1/extract/results/validate/".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "task_id": task_id,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[Union[ExtractResultValidateOut, None, None, None, None, HTTPValidationError]]:
    if response.status_code == 200:
        response_200 = ExtractResultValidateOut.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 403:
        response_403 = None

        return response_403
    if response.status_code == 404:
        response_404 = None

        return response_404
    if response.status_code == 400:
        response_400 = None

        return response_400
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[Union[ExtractResultValidateOut, None, None, None, None, HTTPValidationError]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    task_id: int,
) -> Response[Union[ExtractResultValidateOut, None, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        task_id=task_id,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    task_id: int,
) -> Optional[Union[ExtractResultValidateOut, None, None, None, None, HTTPValidationError]]:
    """Get the next prediction to manually validate in an extract task.

    Only orgadmins can validate predictions, and they can only validate the predictions of their
    own paragraph tasks.

    Value tasks don't need manual validation."""

    return sync_detailed(
        client=client,
        task_id=task_id,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    task_id: int,
) -> Response[Union[ExtractResultValidateOut, None, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        task_id=task_id,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    task_id: int,
) -> Optional[Union[ExtractResultValidateOut, None, None, None, None, HTTPValidationError]]:
    """Get the next prediction to manually validate in an extract task.

    Only orgadmins can validate predictions, and they can only validate the predictions of their
    own paragraph tasks.

    Value tasks don't need manual validation."""

    return (
        await asyncio_detailed(
            client=client,
            task_id=task_id,
        )
    ).parsed



from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.metadata_date_range import MetadataDateRange
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    metadata_id: int,
    json_body: MetadataDateRange,
    folder_id: Union[Unset, int] = UNSET,
    version_id: Union[Unset, int] = UNSET,
    value: Union[Unset, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/api/v1/metadata/{metadata_id}/value/".format(client.base_url, metadata_id=metadata_id)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "folder_id": folder_id,
        "version_id": version_id,
        "value": value,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[None, None, None, None, None]]:
    if response.status_code == 204:
        response_204 = None

        return response_204
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 422:
        response_422 = None

        return response_422
    if response.status_code == 403:
        response_403 = None

        return response_403
    if response.status_code == 404:
        response_404 = None

        return response_404
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[None, None, None, None, None]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    metadata_id: int,
    json_body: MetadataDateRange,
    folder_id: Union[Unset, int] = UNSET,
    version_id: Union[Unset, int] = UNSET,
    value: Union[Unset, str] = UNSET,
) -> Response[Union[None, None, None, None, None]]:
    kwargs = _get_kwargs(
        client=client,
        metadata_id=metadata_id,
        json_body=json_body,
        folder_id=folder_id,
        version_id=version_id,
        value=value,
    )

    response = httpx.put(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    metadata_id: int,
    json_body: MetadataDateRange,
    folder_id: Union[Unset, int] = UNSET,
    version_id: Union[Unset, int] = UNSET,
    value: Union[Unset, str] = UNSET,
) -> Optional[Union[None, None, None, None, None]]:
    """Assign a value to a metadata in some documents.
    Only orgadmins can assign values to metadata.
    - If the version parameter is passed,
        the specified value is assigned to the version.
    - If the folder parameter is passed,
        the specified value is assigned to all documents in the folder and its children.
    - If neither version or folder is passed,
        the value is assigned to all documents' current versions."""

    return sync_detailed(
        client=client,
        metadata_id=metadata_id,
        json_body=json_body,
        folder_id=folder_id,
        version_id=version_id,
        value=value,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    metadata_id: int,
    json_body: MetadataDateRange,
    folder_id: Union[Unset, int] = UNSET,
    version_id: Union[Unset, int] = UNSET,
    value: Union[Unset, str] = UNSET,
) -> Response[Union[None, None, None, None, None]]:
    kwargs = _get_kwargs(
        client=client,
        metadata_id=metadata_id,
        json_body=json_body,
        folder_id=folder_id,
        version_id=version_id,
        value=value,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.put(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    metadata_id: int,
    json_body: MetadataDateRange,
    folder_id: Union[Unset, int] = UNSET,
    version_id: Union[Unset, int] = UNSET,
    value: Union[Unset, str] = UNSET,
) -> Optional[Union[None, None, None, None, None]]:
    """Assign a value to a metadata in some documents.
    Only orgadmins can assign values to metadata.
    - If the version parameter is passed,
        the specified value is assigned to the version.
    - If the folder parameter is passed,
        the specified value is assigned to all documents in the folder and its children.
    - If neither version or folder is passed,
        the value is assigned to all documents' current versions."""

    return (
        await asyncio_detailed(
            client=client,
            metadata_id=metadata_id,
            json_body=json_body,
            folder_id=folder_id,
            version_id=version_id,
            value=value,
        )
    ).parsed



from enum import Enum


class FilterOperator(str, Enum):
    EQ = "eq"
    NEQ = "neq"
    IN_ = "in"
    NIN = "nin"
    GT = "gt"
    GTE = "gte"
    LT = "lt"
    LTE = "lte"
    BTW = "btw"
    NBTW = "nbtw"
    WTHN = "wthn"
    NWTHN = "nwthn"
    CTN = "ctn"
    NCTN = "nctn"
    INT = "int"
    NINT = "nint"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.file_item_move import FileItemMove
from ...models.file_item_out import FileItemOut
from ...models.http_validation_error import HTTPValidationError
from ...types import Response


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    file_id: int,
    json_body: FileItemMove,
) -> Dict[str, Any]:
    url = "{}/api/v1/files/{file_id}/move/".format(client.base_url, file_id=file_id)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[Union[FileItemOut, None, None, None, None, HTTPValidationError]]:
    if response.status_code == 200:
        response_200 = FileItemOut.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 409:
        response_409 = None

        return response_409
    if response.status_code == 404:
        response_404 = None

        return response_404
    if response.status_code == 403:
        response_403 = None

        return response_403
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[Union[FileItemOut, None, None, None, None, HTTPValidationError]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    file_id: int,
    json_body: FileItemMove,
) -> Response[Union[FileItemOut, None, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        file_id=file_id,
        json_body=json_body,
    )

    response = httpx.put(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    file_id: int,
    json_body: FileItemMove,
) -> Optional[Union[FileItemOut, None, None, None, None, HTTPValidationError]]:
    """Moves a file item.

    Modifies the file's parent folder id. The target folder must belong to
    the same organization, and the user must have write rights on it.

    The changes are also applied to all of the file item's versions.
    - Basic users can only update files in folders they has write rights on.
    - Orgadmins can update files in any of their organization's folders."""

    return sync_detailed(
        client=client,
        file_id=file_id,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    file_id: int,
    json_body: FileItemMove,
) -> Response[Union[FileItemOut, None, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        file_id=file_id,
        json_body=json_body,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.put(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    file_id: int,
    json_body: FileItemMove,
) -> Optional[Union[FileItemOut, None, None, None, None, HTTPValidationError]]:
    """Moves a file item.

    Modifies the file's parent folder id. The target folder must belong to
    the same organization, and the user must have write rights on it.

    The changes are also applied to all of the file item's versions.
    - Basic users can only update files in folders they has write rights on.
    - Orgadmins can update files in any of their organization's folders."""

    return (
        await asyncio_detailed(
            client=client,
            file_id=file_id,
            json_body=json_body,
        )
    ).parsed



from enum import Enum


class OrderByUsers(str, Enum):
    FIRST_NAME = "first_name"
    LAST_NAME = "last_name"
    EMAIL = "email"
    CREATED_ON = "created_on"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.analyzer_language import AnalyzerLanguage
from ..types import UNSET, Unset

T = TypeVar("T", bound="SearchConfigurationOut")


@attr.s(auto_attribs=True)
class SearchConfigurationOut:
    """ Search Configuration schema for get return. """

    org_id: int
    auto_semantic: bool
    lemma_language: AnalyzerLanguage
    stop_words_language: AnalyzerLanguage
    skip_neural: bool
    metadata_boost: bool
    auto_suggest: bool
    lemmatization: bool
    stop_words: bool
    nb_synonyms: int
    manual_weight: Union[Unset, float] = UNSET
    updated_on: Union[Unset, datetime.datetime] = UNSET
    updated_by: Union[Unset, int] = UNSET
    synonyms_updated_on: Union[Unset, datetime.datetime] = UNSET
    synonyms_updated_by: Union[Unset, int] = UNSET
    synonyms_file: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        org_id = self.org_id
        auto_semantic = self.auto_semantic
        lemma_language = self.lemma_language.value

        stop_words_language = self.stop_words_language.value

        skip_neural = self.skip_neural
        metadata_boost = self.metadata_boost
        auto_suggest = self.auto_suggest
        lemmatization = self.lemmatization
        stop_words = self.stop_words
        nb_synonyms = self.nb_synonyms
        manual_weight = self.manual_weight
        updated_on: Union[Unset, str] = UNSET
        if not isinstance(self.updated_on, Unset):
            updated_on = self.updated_on.isoformat()

        updated_by = self.updated_by
        synonyms_updated_on: Union[Unset, str] = UNSET
        if not isinstance(self.synonyms_updated_on, Unset):
            synonyms_updated_on = self.synonyms_updated_on.isoformat()

        synonyms_updated_by = self.synonyms_updated_by
        synonyms_file = self.synonyms_file

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "org_id": org_id,
                "auto_semantic": auto_semantic,
                "lemma_language": lemma_language,
                "stop_words_language": stop_words_language,
                "skip_neural": skip_neural,
                "metadata_boost": metadata_boost,
                "auto_suggest": auto_suggest,
                "lemmatization": lemmatization,
                "stop_words": stop_words,
                "nb_synonyms": nb_synonyms,
            }
        )
        if manual_weight is not UNSET:
            field_dict["manual_weight"] = manual_weight
        if updated_on is not UNSET:
            field_dict["updated_on"] = updated_on
        if updated_by is not UNSET:
            field_dict["updated_by"] = updated_by
        if synonyms_updated_on is not UNSET:
            field_dict["synonyms_updated_on"] = synonyms_updated_on
        if synonyms_updated_by is not UNSET:
            field_dict["synonyms_updated_by"] = synonyms_updated_by
        if synonyms_file is not UNSET:
            field_dict["synonyms_file"] = synonyms_file

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        org_id = d.pop("org_id")

        auto_semantic = d.pop("auto_semantic")

        lemma_language = AnalyzerLanguage(d.pop("lemma_language"))

        stop_words_language = AnalyzerLanguage(d.pop("stop_words_language"))

        skip_neural = d.pop("skip_neural")

        metadata_boost = d.pop("metadata_boost")

        auto_suggest = d.pop("auto_suggest")

        lemmatization = d.pop("lemmatization")

        stop_words = d.pop("stop_words")

        nb_synonyms = d.pop("nb_synonyms")

        manual_weight = d.pop("manual_weight", UNSET)

        updated_on: Union[Unset, datetime.datetime] = UNSET
        _updated_on = d.pop("updated_on", UNSET)
        if not isinstance(_updated_on, Unset):
            updated_on = isoparse(_updated_on)

        updated_by = d.pop("updated_by", UNSET)

        synonyms_updated_on: Union[Unset, datetime.datetime] = UNSET
        _synonyms_updated_on = d.pop("synonyms_updated_on", UNSET)
        if not isinstance(_synonyms_updated_on, Unset):
            synonyms_updated_on = isoparse(_synonyms_updated_on)

        synonyms_updated_by = d.pop("synonyms_updated_by", UNSET)

        synonyms_file = d.pop("synonyms_file", UNSET)

        search_configuration_out = cls(
            org_id=org_id,
            auto_semantic=auto_semantic,
            lemma_language=lemma_language,
            stop_words_language=stop_words_language,
            skip_neural=skip_neural,
            metadata_boost=metadata_boost,
            auto_suggest=auto_suggest,
            lemmatization=lemmatization,
            stop_words=stop_words,
            nb_synonyms=nb_synonyms,
            manual_weight=manual_weight,
            updated_on=updated_on,
            updated_by=updated_by,
            synonyms_updated_on=synonyms_updated_on,
            synonyms_updated_by=synonyms_updated_by,
            synonyms_file=synonyms_file,
        )

        search_configuration_out.additional_properties = d
        return search_configuration_out

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.body_create_file_api_v1_files_post import BodyCreateFileApiV1Files_Post
from ...models.file_item_out_with_latest_version import FileItemOutWithLatestVersion
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    multipart_data: BodyCreateFileApiV1Files_Post,
    filename: Union[Unset, str] = UNSET,
    idx_task_id: Union[Unset, int] = UNSET,
    incremental: Union[Unset, bool] = False,
) -> Dict[str, Any]:
    url = "{}/api/v1/files/".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "filename": filename,
        "idx_task_id": idx_task_id,
        "incremental": incremental,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "files": multipart_data.to_dict(),
        "params": params,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[Union[FileItemOutWithLatestVersion, None, None, None, None, None, HTTPValidationError]]:
    if response.status_code == 201:
        response_201 = FileItemOutWithLatestVersion.from_dict(response.json())

        return response_201
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 404:
        response_404 = None

        return response_404
    if response.status_code == 400:
        response_400 = None

        return response_400
    if response.status_code == 403:
        response_403 = None

        return response_403
    if response.status_code == 409:
        response_409 = None

        return response_409
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[Union[FileItemOutWithLatestVersion, None, None, None, None, None, HTTPValidationError]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    multipart_data: BodyCreateFileApiV1Files_Post,
    filename: Union[Unset, str] = UNSET,
    idx_task_id: Union[Unset, int] = UNSET,
    incremental: Union[Unset, bool] = False,
) -> Response[Union[FileItemOutWithLatestVersion, None, None, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        multipart_data=multipart_data,
        filename=filename,
        idx_task_id=idx_task_id,
        incremental=incremental,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    multipart_data: BodyCreateFileApiV1Files_Post,
    filename: Union[Unset, str] = UNSET,
    idx_task_id: Union[Unset, int] = UNSET,
    incremental: Union[Unset, bool] = False,
) -> Optional[Union[FileItemOutWithLatestVersion, None, None, None, None, None, HTTPValidationError]]:
    """Creates a new file item.

    If no file item with same name is in the folder,
    the route creates a new file item and its first version.<br>
    If a file item with same name already exists in the folder,
    the organization versioning policy is applied:
    - If the hash of the uploaded file is the same as the last version,
    nothing is done.
    - If versioning is disabled, the previous item version is deleted,
    and the uploaded one replaces it.
    - If versioning is enabled, a new item version is created.

    If current number of versions exceeds the maximum number defined in the policy,
    the oldest version is deleted.

    An optional idx_task_id query parameter may be passed to the route,
    which will be saved on the file.

    An incremental query parameter could be passed
    to specify if the task item number should be incremented.

    - Basic users can only add files in folders they has write rights on.
    - Orgadmins can add files in any of their organization's folders.
    - Services can also add files within their organization."""

    return sync_detailed(
        client=client,
        multipart_data=multipart_data,
        filename=filename,
        idx_task_id=idx_task_id,
        incremental=incremental,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    multipart_data: BodyCreateFileApiV1Files_Post,
    filename: Union[Unset, str] = UNSET,
    idx_task_id: Union[Unset, int] = UNSET,
    incremental: Union[Unset, bool] = False,
) -> Response[Union[FileItemOutWithLatestVersion, None, None, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        multipart_data=multipart_data,
        filename=filename,
        idx_task_id=idx_task_id,
        incremental=incremental,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    multipart_data: BodyCreateFileApiV1Files_Post,
    filename: Union[Unset, str] = UNSET,
    idx_task_id: Union[Unset, int] = UNSET,
    incremental: Union[Unset, bool] = False,
) -> Optional[Union[FileItemOutWithLatestVersion, None, None, None, None, None, HTTPValidationError]]:
    """Creates a new file item.

    If no file item with same name is in the folder,
    the route creates a new file item and its first version.<br>
    If a file item with same name already exists in the folder,
    the organization versioning policy is applied:
    - If the hash of the uploaded file is the same as the last version,
    nothing is done.
    - If versioning is disabled, the previous item version is deleted,
    and the uploaded one replaces it.
    - If versioning is enabled, a new item version is created.

    If current number of versions exceeds the maximum number defined in the policy,
    the oldest version is deleted.

    An optional idx_task_id query parameter may be passed to the route,
    which will be saved on the file.

    An incremental query parameter could be passed
    to specify if the task item number should be incremented.

    - Basic users can only add files in folders they has write rights on.
    - Orgadmins can add files in any of their organization's folders.
    - Services can also add files within their organization."""

    return (
        await asyncio_detailed(
            client=client,
            multipart_data=multipart_data,
            filename=filename,
            idx_task_id=idx_task_id,
            incremental=incremental,
        )
    ).parsed



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.version_metadata import VersionMetadata
from ..types import UNSET, Unset

T = TypeVar("T", bound="Version")


@attr.s(auto_attribs=True)
class Version:
    """ File Version schema. """

    id: int
    org_id: int
    folder_id: int
    item_id: int
    name: str
    display_name: str
    size: int
    extension: str
    is_current_version: bool
    title: Union[Unset, str] = UNSET
    text: Union[Unset, str] = UNSET
    author: Union[Unset, str] = UNSET
    language: Union[Unset, str] = UNSET
    num_pages: Union[Unset, int] = UNSET
    metadata: Union[VersionMetadata, Unset] = UNSET
    chunked: Union[Unset, bool] = False
    chunk_timestamp: Union[Unset, datetime.datetime] = UNSET
    ocr: Union[Unset, bool] = False
    created_on: Union[Unset, datetime.datetime] = UNSET
    updated_on: Union[Unset, datetime.datetime] = UNSET
    idx_task_id: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        org_id = self.org_id
        folder_id = self.folder_id
        item_id = self.item_id
        name = self.name
        display_name = self.display_name
        size = self.size
        extension = self.extension
        is_current_version = self.is_current_version
        title = self.title
        text = self.text
        author = self.author
        language = self.language
        num_pages = self.num_pages
        metadata: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.metadata, Unset):
            metadata = self.metadata.to_dict()

        chunked = self.chunked
        chunk_timestamp: Union[Unset, str] = UNSET
        if not isinstance(self.chunk_timestamp, Unset):
            chunk_timestamp = self.chunk_timestamp.isoformat()

        ocr = self.ocr
        created_on: Union[Unset, str] = UNSET
        if not isinstance(self.created_on, Unset):
            created_on = self.created_on.isoformat()

        updated_on: Union[Unset, str] = UNSET
        if not isinstance(self.updated_on, Unset):
            updated_on = self.updated_on.isoformat()

        idx_task_id = self.idx_task_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "id": id,
                "org_id": org_id,
                "folder_id": folder_id,
                "item_id": item_id,
                "name": name,
                "display_name": display_name,
                "size": size,
                "extension": extension,
                "is_current_version": is_current_version,
            }
        )
        if title is not UNSET:
            field_dict["title"] = title
        if text is not UNSET:
            field_dict["text"] = text
        if author is not UNSET:
            field_dict["author"] = author
        if language is not UNSET:
            field_dict["language"] = language
        if num_pages is not UNSET:
            field_dict["num_pages"] = num_pages
        if metadata is not UNSET:
            field_dict["metadata"] = metadata
        if chunked is not UNSET:
            field_dict["chunked"] = chunked
        if chunk_timestamp is not UNSET:
            field_dict["chunk_timestamp"] = chunk_timestamp
        if ocr is not UNSET:
            field_dict["ocr"] = ocr
        if created_on is not UNSET:
            field_dict["created_on"] = created_on
        if updated_on is not UNSET:
            field_dict["updated_on"] = updated_on
        if idx_task_id is not UNSET:
            field_dict["idx_task_id"] = idx_task_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id")

        org_id = d.pop("org_id")

        folder_id = d.pop("folder_id")

        item_id = d.pop("item_id")

        name = d.pop("name")

        display_name = d.pop("display_name")

        size = d.pop("size")

        extension = d.pop("extension")

        is_current_version = d.pop("is_current_version")

        title = d.pop("title", UNSET)

        text = d.pop("text", UNSET)

        author = d.pop("author", UNSET)

        language = d.pop("language", UNSET)

        num_pages = d.pop("num_pages", UNSET)

        metadata: Union[VersionMetadata, Unset] = UNSET
        _metadata = d.pop("metadata", UNSET)
        if not isinstance(_metadata, Unset):
            metadata = VersionMetadata.from_dict(_metadata)

        chunked = d.pop("chunked", UNSET)

        chunk_timestamp: Union[Unset, datetime.datetime] = UNSET
        _chunk_timestamp = d.pop("chunk_timestamp", UNSET)
        if not isinstance(_chunk_timestamp, Unset):
            chunk_timestamp = isoparse(_chunk_timestamp)

        ocr = d.pop("ocr", UNSET)

        created_on: Union[Unset, datetime.datetime] = UNSET
        _created_on = d.pop("created_on", UNSET)
        if not isinstance(_created_on, Unset):
            created_on = isoparse(_created_on)

        updated_on: Union[Unset, datetime.datetime] = UNSET
        _updated_on = d.pop("updated_on", UNSET)
        if not isinstance(_updated_on, Unset):
            updated_on = isoparse(_updated_on)

        idx_task_id = d.pop("idx_task_id", UNSET)

        version = cls(
            id=id,
            org_id=org_id,
            folder_id=folder_id,
            item_id=item_id,
            name=name,
            display_name=display_name,
            size=size,
            extension=extension,
            is_current_version=is_current_version,
            title=title,
            text=text,
            author=author,
            language=language,
            num_pages=num_pages,
            metadata=metadata,
            chunked=chunked,
            chunk_timestamp=chunk_timestamp,
            ocr=ocr,
            created_on=created_on,
            updated_on=updated_on,
            idx_task_id=idx_task_id,
        )

        version.additional_properties = d
        return version

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr
from dateutil.parser import isoparse

from ..models.block_from_digester import BlockFromDigester
from ..models.chunk_out_coordinates import ChunkOutCoordinates
from ..models.chunk_out_div_idxs import ChunkOutDivIdxs
from ..models.chunk_out_metadata import ChunkOutMetadata
from ..types import UNSET, Unset

T = TypeVar("T", bound="ChunkOut")


@attr.s(auto_attribs=True)
class ChunkOut:
    """ Chunk return schema. """

    div_idxs: ChunkOutDivIdxs
    text: str
    pages: List[int]
    name: str
    display_name: str
    folder_id: int
    item_id: int
    extension: str
    is_current_version: bool
    size: int
    ocr: bool
    id: str
    version_id: int
    tag_names: Union[Unset, List[str]] = UNSET
    blocks: Union[Unset, List[BlockFromDigester]] = UNSET
    coordinates: Union[ChunkOutCoordinates, Unset] = UNSET
    language: Union[Unset, str] = UNSET
    title: Union[Unset, str] = UNSET
    author: Union[Unset, str] = UNSET
    metadata: Union[ChunkOutMetadata, Unset] = UNSET
    num_pages: Union[Unset, int] = UNSET
    created_on: Union[Unset, datetime.datetime] = UNSET
    updated_on: Union[Unset, datetime.datetime] = UNSET
    embedding: Union[Unset, List[float]] = UNSET
    is_semantic: Union[Unset, bool] = False
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        div_idxs = self.div_idxs.to_dict()

        text = self.text
        pages = self.pages

        name = self.name
        display_name = self.display_name
        folder_id = self.folder_id
        item_id = self.item_id
        extension = self.extension
        is_current_version = self.is_current_version
        size = self.size
        ocr = self.ocr
        id = self.id
        version_id = self.version_id
        tag_names: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.tag_names, Unset):
            tag_names = self.tag_names

        blocks: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.blocks, Unset):
            blocks = []
            for blocks_item_data in self.blocks:
                blocks_item = blocks_item_data.to_dict()

                blocks.append(blocks_item)

        coordinates: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.coordinates, Unset):
            coordinates = self.coordinates.to_dict()

        language = self.language
        title = self.title
        author = self.author
        metadata: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.metadata, Unset):
            metadata = self.metadata.to_dict()

        num_pages = self.num_pages
        created_on: Union[Unset, str] = UNSET
        if not isinstance(self.created_on, Unset):
            created_on = self.created_on.isoformat()

        updated_on: Union[Unset, str] = UNSET
        if not isinstance(self.updated_on, Unset):
            updated_on = self.updated_on.isoformat()

        embedding: Union[Unset, List[Any]] = UNSET
        if not isinstance(self.embedding, Unset):
            embedding = self.embedding

        is_semantic = self.is_semantic

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "div_idxs": div_idxs,
                "text": text,
                "pages": pages,
                "name": name,
                "display_name": display_name,
                "folder_id": folder_id,
                "item_id": item_id,
                "extension": extension,
                "is_current_version": is_current_version,
                "size": size,
                "ocr": ocr,
                "id": id,
                "version_id": version_id,
            }
        )
        if tag_names is not UNSET:
            field_dict["tag_names"] = tag_names
        if blocks is not UNSET:
            field_dict["blocks"] = blocks
        if coordinates is not UNSET:
            field_dict["coordinates"] = coordinates
        if language is not UNSET:
            field_dict["language"] = language
        if title is not UNSET:
            field_dict["title"] = title
        if author is not UNSET:
            field_dict["author"] = author
        if metadata is not UNSET:
            field_dict["metadata"] = metadata
        if num_pages is not UNSET:
            field_dict["num_pages"] = num_pages
        if created_on is not UNSET:
            field_dict["created_on"] = created_on
        if updated_on is not UNSET:
            field_dict["updated_on"] = updated_on
        if embedding is not UNSET:
            field_dict["embedding"] = embedding
        if is_semantic is not UNSET:
            field_dict["is_semantic"] = is_semantic

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        div_idxs = ChunkOutDivIdxs.from_dict(d.pop("div_idxs"))

        text = d.pop("text")

        pages = cast(List[int], d.pop("pages"))

        name = d.pop("name")

        display_name = d.pop("display_name")

        folder_id = d.pop("folder_id")

        item_id = d.pop("item_id")

        extension = d.pop("extension")

        is_current_version = d.pop("is_current_version")

        size = d.pop("size")

        ocr = d.pop("ocr")

        id = d.pop("id")

        version_id = d.pop("version_id")

        tag_names = cast(List[str], d.pop("tag_names", UNSET))

        blocks = []
        _blocks = d.pop("blocks", UNSET)
        for blocks_item_data in _blocks or []:
            blocks_item = BlockFromDigester.from_dict(blocks_item_data)

            blocks.append(blocks_item)

        coordinates: Union[ChunkOutCoordinates, Unset] = UNSET
        _coordinates = d.pop("coordinates", UNSET)
        if not isinstance(_coordinates, Unset):
            coordinates = ChunkOutCoordinates.from_dict(_coordinates)

        language = d.pop("language", UNSET)

        title = d.pop("title", UNSET)

        author = d.pop("author", UNSET)

        metadata: Union[ChunkOutMetadata, Unset] = UNSET
        _metadata = d.pop("metadata", UNSET)
        if not isinstance(_metadata, Unset):
            metadata = ChunkOutMetadata.from_dict(_metadata)

        num_pages = d.pop("num_pages", UNSET)

        created_on: Union[Unset, datetime.datetime] = UNSET
        _created_on = d.pop("created_on", UNSET)
        if not isinstance(_created_on, Unset):
            created_on = isoparse(_created_on)

        updated_on: Union[Unset, datetime.datetime] = UNSET
        _updated_on = d.pop("updated_on", UNSET)
        if not isinstance(_updated_on, Unset):
            updated_on = isoparse(_updated_on)

        embedding = cast(List[float], d.pop("embedding", UNSET))

        is_semantic = d.pop("is_semantic", UNSET)

        chunk_out = cls(
            div_idxs=div_idxs,
            text=text,
            pages=pages,
            name=name,
            display_name=display_name,
            folder_id=folder_id,
            item_id=item_id,
            extension=extension,
            is_current_version=is_current_version,
            size=size,
            ocr=ocr,
            id=id,
            version_id=version_id,
            tag_names=tag_names,
            blocks=blocks,
            coordinates=coordinates,
            language=language,
            title=title,
            author=author,
            metadata=metadata,
            num_pages=num_pages,
            created_on=created_on,
            updated_on=updated_on,
            embedding=embedding,
            is_semantic=is_semantic,
        )

        chunk_out.additional_properties = d
        return chunk_out

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.document_result_metadata import DocumentResultMetadata
from ..types import UNSET, Unset

T = TypeVar("T", bound="DocumentResult")


@attr.s(auto_attribs=True)
class DocumentResult:
    """ Document result schema. """

    name: str
    display_name: str
    folder_id: int
    item_id: int
    extension: str
    is_current_version: bool
    size: int
    ocr: bool
    id: int
    title: Union[Unset, str] = UNSET
    author: Union[Unset, str] = UNSET
    metadata: Union[DocumentResultMetadata, Unset] = UNSET
    num_pages: Union[Unset, int] = UNSET
    created_on: Union[Unset, datetime.datetime] = UNSET
    updated_on: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        display_name = self.display_name
        folder_id = self.folder_id
        item_id = self.item_id
        extension = self.extension
        is_current_version = self.is_current_version
        size = self.size
        ocr = self.ocr
        id = self.id
        title = self.title
        author = self.author
        metadata: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.metadata, Unset):
            metadata = self.metadata.to_dict()

        num_pages = self.num_pages
        created_on: Union[Unset, str] = UNSET
        if not isinstance(self.created_on, Unset):
            created_on = self.created_on.isoformat()

        updated_on: Union[Unset, str] = UNSET
        if not isinstance(self.updated_on, Unset):
            updated_on = self.updated_on.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "display_name": display_name,
                "folder_id": folder_id,
                "item_id": item_id,
                "extension": extension,
                "is_current_version": is_current_version,
                "size": size,
                "ocr": ocr,
                "id": id,
            }
        )
        if title is not UNSET:
            field_dict["title"] = title
        if author is not UNSET:
            field_dict["author"] = author
        if metadata is not UNSET:
            field_dict["metadata"] = metadata
        if num_pages is not UNSET:
            field_dict["num_pages"] = num_pages
        if created_on is not UNSET:
            field_dict["created_on"] = created_on
        if updated_on is not UNSET:
            field_dict["updated_on"] = updated_on

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        display_name = d.pop("display_name")

        folder_id = d.pop("folder_id")

        item_id = d.pop("item_id")

        extension = d.pop("extension")

        is_current_version = d.pop("is_current_version")

        size = d.pop("size")

        ocr = d.pop("ocr")

        id = d.pop("id")

        title = d.pop("title", UNSET)

        author = d.pop("author", UNSET)

        metadata: Union[DocumentResultMetadata, Unset] = UNSET
        _metadata = d.pop("metadata", UNSET)
        if not isinstance(_metadata, Unset):
            metadata = DocumentResultMetadata.from_dict(_metadata)

        num_pages = d.pop("num_pages", UNSET)

        created_on: Union[Unset, datetime.datetime] = UNSET
        _created_on = d.pop("created_on", UNSET)
        if not isinstance(_created_on, Unset):
            created_on = isoparse(_created_on)

        updated_on: Union[Unset, datetime.datetime] = UNSET
        _updated_on = d.pop("updated_on", UNSET)
        if not isinstance(_updated_on, Unset):
            updated_on = isoparse(_updated_on)

        document_result = cls(
            name=name,
            display_name=display_name,
            folder_id=folder_id,
            item_id=item_id,
            extension=extension,
            is_current_version=is_current_version,
            size=size,
            ocr=ocr,
            id=id,
            title=title,
            author=author,
            metadata=metadata,
            num_pages=num_pages,
            created_on=created_on,
            updated_on=updated_on,
        )

        document_result.additional_properties = d
        return document_result

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.product import Product
from ..types import UNSET, Unset

T = TypeVar("T", bound="OrganizationOut")


@attr.s(auto_attribs=True)
class OrganizationOut:
    """ Organization schema to output from GET methods. """

    id: int
    n_users: int
    n_groups: int
    name: Union[Unset, str] = UNSET
    product: Union[Unset, Product] = UNSET
    license_expires_on: Union[Unset, datetime.datetime] = UNSET
    license_type: Union[Unset, str] = UNSET
    n_docs: Union[Unset, int] = 0
    two_factor: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        n_users = self.n_users
        n_groups = self.n_groups
        name = self.name
        product: Union[Unset, Product] = UNSET
        if not isinstance(self.product, Unset):
            product = self.product

        license_expires_on: Union[Unset, str] = UNSET
        if not isinstance(self.license_expires_on, Unset):
            license_expires_on = self.license_expires_on.isoformat()

        license_type = self.license_type
        n_docs = self.n_docs
        two_factor = self.two_factor

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "id": id,
                "n_users": n_users,
                "n_groups": n_groups,
            }
        )
        if name is not UNSET:
            field_dict["name"] = name
        if product is not UNSET:
            field_dict["product"] = product
        if license_expires_on is not UNSET:
            field_dict["license_expires_on"] = license_expires_on
        if license_type is not UNSET:
            field_dict["license_type"] = license_type
        if n_docs is not UNSET:
            field_dict["n_docs"] = n_docs
        if two_factor is not UNSET:
            field_dict["two_factor"] = two_factor

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id")

        n_users = d.pop("n_users")

        n_groups = d.pop("n_groups")

        name = d.pop("name", UNSET)

        product: Union[Unset, Product] = UNSET
        _product = d.pop("product", UNSET)
        if not isinstance(_product, Unset):
            product = Product(_product)

        license_expires_on: Union[Unset, datetime.datetime] = UNSET
        _license_expires_on = d.pop("license_expires_on", UNSET)
        if not isinstance(_license_expires_on, Unset):
            license_expires_on = isoparse(_license_expires_on)

        license_type = d.pop("license_type", UNSET)

        n_docs = d.pop("n_docs", UNSET)

        two_factor = d.pop("two_factor", UNSET)

        organization_out = cls(
            id=id,
            n_users=n_users,
            n_groups=n_groups,
            name=name,
            product=product,
            license_expires_on=license_expires_on,
            license_type=license_type,
            n_docs=n_docs,
            two_factor=two_factor,
        )

        organization_out.additional_properties = d
        return organization_out

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="EmailTemplateUpdate")


@attr.s(auto_attribs=True)
class EmailTemplateUpdate:
    """ Email Template update schema. """

    display_name: Union[Unset, str] = UNSET
    subject: Union[Unset, str] = UNSET
    body: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        display_name = self.display_name
        subject = self.subject
        body = self.body

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if display_name is not UNSET:
            field_dict["display_name"] = display_name
        if subject is not UNSET:
            field_dict["subject"] = subject
        if body is not UNSET:
            field_dict["body"] = body

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        display_name = d.pop("display_name", UNSET)

        subject = d.pop("subject", UNSET)

        body = d.pop("body", UNSET)

        email_template_update = cls(
            display_name=display_name,
            subject=subject,
            body=body,
        )

        email_template_update.additional_properties = d
        return email_template_update

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.file_item_out_with_versions import FileItemOutWithVersions
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    file_id: int,
    versions: Union[Unset, bool] = False,
) -> Dict[str, Any]:
    url = "{}/api/v1/files/{file_id}/".format(client.base_url, file_id=file_id)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "versions": versions,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[Union[FileItemOutWithVersions, None, None, None, HTTPValidationError]]:
    if response.status_code == 200:
        response_200 = FileItemOutWithVersions.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 404:
        response_404 = None

        return response_404
    if response.status_code == 403:
        response_403 = None

        return response_403
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[Union[FileItemOutWithVersions, None, None, None, HTTPValidationError]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    file_id: int,
    versions: Union[Unset, bool] = False,
) -> Response[Union[FileItemOutWithVersions, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        file_id=file_id,
        versions=versions,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    file_id: int,
    versions: Union[Unset, bool] = False,
) -> Optional[Union[FileItemOutWithVersions, None, None, None, HTTPValidationError]]:
    """Returns a single file item.

    If versions is set to true in the query arguments,
    the route also returns all of the file item versions.
    If not present, or if set to false, no version is returned.
    - Basic users can only access files in folders they have rights on.
    - Orgadmins can access files in all of their organization's folders."""

    return sync_detailed(
        client=client,
        file_id=file_id,
        versions=versions,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    file_id: int,
    versions: Union[Unset, bool] = False,
) -> Response[Union[FileItemOutWithVersions, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        file_id=file_id,
        versions=versions,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    file_id: int,
    versions: Union[Unset, bool] = False,
) -> Optional[Union[FileItemOutWithVersions, None, None, None, HTTPValidationError]]:
    """Returns a single file item.

    If versions is set to true in the query arguments,
    the route also returns all of the file item versions.
    If not present, or if set to false, no version is returned.
    - Basic users can only access files in folders they have rights on.
    - Orgadmins can access files in all of their organization's folders."""

    return (
        await asyncio_detailed(
            client=client,
            file_id=file_id,
            versions=versions,
        )
    ).parsed



from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.extract_result_validate_in import ExtractResultValidateIn
from ...models.extract_result_validate_out import ExtractResultValidateOut
from ...models.http_validation_error import HTTPValidationError
from ...types import Response


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    result_id: int,
    json_body: ExtractResultValidateIn,
) -> Dict[str, Any]:
    url = "{}/api/v1/extract/results/{result_id}/validate/".format(client.base_url, result_id=result_id)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[Union[ExtractResultValidateOut, None, None, None, None, HTTPValidationError]]:
    if response.status_code == 200:
        response_200 = ExtractResultValidateOut.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 204:
        response_204 = None

        return response_204
    if response.status_code == 404:
        response_404 = None

        return response_404
    if response.status_code == 403:
        response_403 = None

        return response_403
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[Union[ExtractResultValidateOut, None, None, None, None, HTTPValidationError]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    result_id: int,
    json_body: ExtractResultValidateIn,
) -> Response[Union[ExtractResultValidateOut, None, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        result_id=result_id,
        json_body=json_body,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    result_id: int,
    json_body: ExtractResultValidateIn,
) -> Optional[Union[ExtractResultValidateOut, None, None, None, None, HTTPValidationError]]:
    """Validates one or no prediction made for a document.

    Only orgadmins can validate predictions, and they can only validate the predictions of
    their own tasks.

    If none of the proposed chunks is the one we're looking for, we consider that no paragraph
    has been found in the document.

    When a manual validation occurs, only the validated chunk, if any, is kept,
    the other proposed chunks are deleted.

    If there are documents left to validate, the endpoint returns the next one.

    If there is no more document to validate, the endpoint returns a 204."""

    return sync_detailed(
        client=client,
        result_id=result_id,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    result_id: int,
    json_body: ExtractResultValidateIn,
) -> Response[Union[ExtractResultValidateOut, None, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        result_id=result_id,
        json_body=json_body,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    result_id: int,
    json_body: ExtractResultValidateIn,
) -> Optional[Union[ExtractResultValidateOut, None, None, None, None, HTTPValidationError]]:
    """Validates one or no prediction made for a document.

    Only orgadmins can validate predictions, and they can only validate the predictions of
    their own tasks.

    If none of the proposed chunks is the one we're looking for, we consider that no paragraph
    has been found in the document.

    When a manual validation occurs, only the validated chunk, if any, is kept,
    the other proposed chunks are deleted.

    If there are documents left to validate, the endpoint returns the next one.

    If there is no more document to validate, the endpoint returns a 204."""

    return (
        await asyncio_detailed(
            client=client,
            result_id=result_id,
            json_body=json_body,
        )
    ).parsed



from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.folder_create import FolderCreate
from ...models.folder_out import FolderOut
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    json_body: FolderCreate,
    ignore_conflicts: Union[Unset, bool] = False,
) -> Dict[str, Any]:
    url = "{}/api/v1/folders/".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {
        "ignore_conflicts": ignore_conflicts,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
        "params": params,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[Union[FolderOut, None, None, None, None, HTTPValidationError]]:
    if response.status_code == 201:
        response_201 = FolderOut.from_dict(response.json())

        return response_201
    if response.status_code == 401:
        response_401 = None

        return response_401
    if response.status_code == 404:
        response_404 = None

        return response_404
    if response.status_code == 403:
        response_403 = None

        return response_403
    if response.status_code == 409:
        response_409 = None

        return response_409
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[Union[FolderOut, None, None, None, None, HTTPValidationError]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    json_body: FolderCreate,
    ignore_conflicts: Union[Unset, bool] = False,
) -> Response[Union[FolderOut, None, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
        ignore_conflicts=ignore_conflicts,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    json_body: FolderCreate,
    ignore_conflicts: Union[Unset, bool] = False,
) -> Optional[Union[FolderOut, None, None, None, None, HTTPValidationError]]:
    """Creates a new folder.

    To be allowed to create a folder, a user must either:
    - be orgadmin: they can create a folder in their organization file system.
    - have write rights on the parent folder if they are basic users.

    Additionally, services can also create folders.

    The constraints of folder creation are:

    - Two folders with same parent cannot have the same name."""

    return sync_detailed(
        client=client,
        json_body=json_body,
        ignore_conflicts=ignore_conflicts,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    json_body: FolderCreate,
    ignore_conflicts: Union[Unset, bool] = False,
) -> Response[Union[FolderOut, None, None, None, None, HTTPValidationError]]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
        ignore_conflicts=ignore_conflicts,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    json_body: FolderCreate,
    ignore_conflicts: Union[Unset, bool] = False,
) -> Optional[Union[FolderOut, None, None, None, None, HTTPValidationError]]:
    """Creates a new folder.

    To be allowed to create a folder, a user must either:
    - be orgadmin: they can create a folder in their organization file system.
    - have write rights on the parent folder if they are basic users.

    Additionally, services can also create folders.

    The constraints of folder creation are:

    - Two folders with same parent cannot have the same name."""

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
            ignore_conflicts=ignore_conflicts,
        )
    ).parsed
